#ifndef GLOBAL_VARSH
#define GLOBAL_VARSH

#ifndef MAIN
#define WORLD extern
#else
#define WORLD
#endif

WORLD int gCopy_atts;
WORLD int gAsciiout;
WORLD char gAscii_type;
#endif
